# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyState import SecurityPolicyState  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.operation.SecurityPolicyOptions import SecurityPolicyOptions  # noqa: F401,E501
from ntnx_microseg_py_client.models.microseg.v4.operation.SecurityPolicyType import SecurityPolicyType  # noqa: F401,E501

class PolicyMetadata(object):

    """The meta information about a Flow Network Security Policy.<br> The info captures the secured Categories, state of policy, policy type, last modified time, previewId and options.<br> The PreviewId can be used to fetch the complete FNS Next-Gen policy preview using Preview GET API.<br> A sample call would look like ``` /microseg/v4.0.a1/operation/policy-preview/8f094d6c-d7b2-32c2-8223-462c6c5e06db ``` 

    :param description: (:attr:`description`) A user defined annotation for a policy metadata during upgrade.
    :type description: 
     max=512 chars
    
    :param secured_group_category_references: (:attr:`secured_group_category_references`) List of categories external IDs being secured by the Flow Network Security Policy.
    :type secured_group_category_references: 
    
    
    :param state: (:attr:`state`) 
    :type state: required
    
    
    :param last_update_time: (:attr:`last_update_time`) Last update time for the network security policy.
    :type last_update_time: 
    
    
    :param type: (:attr:`type`) 
    :type type: 
    
    
    :param preview_reference: (:attr:`preview_reference`) This is a system generated identifier which can be used to preview the complete FNS Next-Gen policy corresponding with a FNS policy using Preview GET API. A sample call would look like ``` /microseg/v4.0.a1/operation/policy-preview/8f094d6c-d7b2-32c2-8223-462c6c5e06db ``` 
    :type preview_reference: 
    
    
    :param options: (:attr:`options`) 
    :type options: 
    
    
    :param name: (:attr:`name`) Name of the network security policy.
    :type name: 
     max=63 chars
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'description': 'str',
        'secured_group_category_references': 'list[str]',
        'state': 'microseg.v4.config.SecurityPolicyState',
        'last_update_time': 'datetime',
        'type': 'microseg.v4.operation.SecurityPolicyType',
        'preview_reference': 'str',
        'options': 'microseg.v4.operation.SecurityPolicyOptions',
        'name': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'description': 'description',
        'secured_group_category_references': 'securedGroupCategoryReferences',
        'state': 'state',
        'last_update_time': 'lastUpdateTime',
        'type': 'type',
        'preview_reference': 'previewReference',
        'options': 'options',
        'name': 'name',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, description=None, secured_group_category_references=None, state=None, last_update_time=None, type=None, preview_reference=None, options=None, name=None, *args, **kwargs):  # noqa: E501
        self.__description = None
        self.__secured_group_category_references = None
        self.__state = None
        self.__last_update_time = None
        self.__type = None
        self.__preview_reference = None
        self.__options = None
        self.__name = None
        self.discriminator = None
        if description is not None:
            self.__description = description
        if secured_group_category_references is not None:
            self.__secured_group_category_references = secured_group_category_references
        self.__state = state
        if last_update_time is not None:
            self.__last_update_time = last_update_time
        if type is not None:
            self.__type = type
        if preview_reference is not None:
            self.__preview_reference = preview_reference
        if options is not None:
            self.__options = options
        if name is not None:
            self.__name = name
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'microseg.v4.operation.PolicyMetadata'

    def _initialize_object_version(self):
        return 'v4.r2'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def description(self):
        """
        A user defined annotation for a policy metadata during upgrade.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__description

    @description.setter
    def description(self, description):
        if description is not None and len(description) > 512:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `512`")  # noqa: E501

        self.__description = description

    @property
    def secured_group_category_references(self):
        """
        List of categories external IDs being secured by the Flow Network Security Policy.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__secured_group_category_references

    @secured_group_category_references.setter
    def secured_group_category_references(self, secured_group_category_references):

        self.__secured_group_category_references = secured_group_category_references

    @property
    def state(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.config.SecurityPolicyState`
        """  # noqa: E501
        return self.__state

    @state.setter
    def state(self, state):
        if state is None:
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self.__state = state

    @property
    def last_update_time(self):
        """
        Last update time for the network security policy.

        :type:
                :class:`~datetime`
        """  # noqa: E501
        return self.__last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):

        self.__last_update_time = last_update_time

    @property
    def type(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.operation.SecurityPolicyType`
        """  # noqa: E501
        return self.__type

    @type.setter
    def type(self, type):

        self.__type = type

    @property
    def preview_reference(self):
        """
        This is a system generated identifier which can be used to preview the complete FNS Next-Gen policy corresponding with a FNS policy using Preview GET API. A sample call would look like ``` /microseg/v4.0.a1/operation/policy-preview/8f094d6c-d7b2-32c2-8223-462c6c5e06db ``` 

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__preview_reference

    @preview_reference.setter
    def preview_reference(self, preview_reference):
        if preview_reference is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', preview_reference):  # noqa: E501
            raise ValueError(r"Invalid value for `preview_reference`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__preview_reference = preview_reference

    @property
    def options(self):
        """
        

        :type:
            :class:`~ntnx_microseg_py_client.models.microseg.v4.operation.SecurityPolicyOptions`
        """  # noqa: E501
        return self.__options

    @options.setter
    def options(self, options):

        self.__options = options

    @property
    def name(self):
        """
        Name of the network security policy.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):
        if name is not None and len(name) > 63:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `63`")  # noqa: E501

        self.__name = name

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(PolicyMetadata, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}

    def _sanitize_for_serialization(self, value):
        """Recursively sanitize the value for serialization.

        :param value: The value to sanitize
        :type value: any
        :return: Sanitized value
        :rtype: any
        """
        if isinstance(value, (list, tuple)):
            return list(map(self._sanitize_for_serialization, [v for v in value if v is not None]))
        elif isinstance(value, dict):
            return {k: self._sanitize_for_serialization(v) for k, v in six.iteritems(value) if v is not None}
        elif isinstance(value, (str, int, float, bool)):
            return value
        elif isinstance(value, Path):
            return str(value)
        else:
            return value.to_dict() if hasattr(value, 'to_dict') else str(value)

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

