# coding: utf-8


"""
IGNORE:
    Nutanix Flow Management APIs

    Manage Network Security Policy configuration of Nutanix clusters.  # noqa: E501

    OpenAPI spec version: 4.2.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_microseg_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_microseg_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501

class SyncPolicy(ExternalizableAbstractModel):

    """

    :param source_domain_manager_ext_id: (:attr:`source_domain_manager_ext_id`) Prism Central from which security policies are being synchronized.
    :type source_domain_manager_ext_id: required
    
    
    :param target_domain_manager_ext_id: (:attr:`target_domain_manager_ext_id`) Prism Central to which security policies are synchronized.
    :type target_domain_manager_ext_id: required
    
    
    :param policy_ext_ids: (:attr:`policy_ext_ids`) List of security policies that are synchronized across a Prism Central pair.
    :type policy_ext_ids: 
    
    
    :param has_sync_compatibility: (:attr:`has_sync_compatibility`) State of the Prism Central pair that determines its capability to synchronize security policies.
    :type has_sync_compatibility: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'source_domain_manager_ext_id': 'str',
        'target_domain_manager_ext_id': 'str',
        'policy_ext_ids': 'list[str]',
        'has_sync_compatibility': 'bool',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'source_domain_manager_ext_id': 'sourceDomainManagerExtId',
        'target_domain_manager_ext_id': 'targetDomainManagerExtId',
        'policy_ext_ids': 'policyExtIds',
        'has_sync_compatibility': 'hasSyncCompatibility',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, source_domain_manager_ext_id=None, target_domain_manager_ext_id=None, policy_ext_ids=None, has_sync_compatibility=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__source_domain_manager_ext_id = None
        self.__target_domain_manager_ext_id = None
        self.__policy_ext_ids = None
        self.__has_sync_compatibility = None
        self.discriminator = None
        self.__source_domain_manager_ext_id = source_domain_manager_ext_id
        self.__target_domain_manager_ext_id = target_domain_manager_ext_id
        if policy_ext_ids is not None:
            self.__policy_ext_ids = policy_ext_ids
        if has_sync_compatibility is not None:
            self.__has_sync_compatibility = has_sync_compatibility

    def _initialize_object_type(self):
        return 'microseg.v4.config.SyncPolicy'

    def _initialize_object_version(self):
        return 'v4.r2'


    @property
    def source_domain_manager_ext_id(self):
        """
        Prism Central from which security policies are being synchronized.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__source_domain_manager_ext_id

    @source_domain_manager_ext_id.setter
    def source_domain_manager_ext_id(self, source_domain_manager_ext_id):
        if source_domain_manager_ext_id is None:
            raise ValueError("Invalid value for `source_domain_manager_ext_id`, must not be `None`")  # noqa: E501
        if source_domain_manager_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', source_domain_manager_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `source_domain_manager_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__source_domain_manager_ext_id = source_domain_manager_ext_id

    @property
    def target_domain_manager_ext_id(self):
        """
        Prism Central to which security policies are synchronized.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__target_domain_manager_ext_id

    @target_domain_manager_ext_id.setter
    def target_domain_manager_ext_id(self, target_domain_manager_ext_id):
        if target_domain_manager_ext_id is None:
            raise ValueError("Invalid value for `target_domain_manager_ext_id`, must not be `None`")  # noqa: E501
        if target_domain_manager_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', target_domain_manager_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `target_domain_manager_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__target_domain_manager_ext_id = target_domain_manager_ext_id

    @property
    def policy_ext_ids(self):
        """
        List of security policies that are synchronized across a Prism Central pair.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__policy_ext_ids

    @policy_ext_ids.setter
    def policy_ext_ids(self, policy_ext_ids):

        self.__policy_ext_ids = policy_ext_ids

    @property
    def has_sync_compatibility(self):
        """
        State of the Prism Central pair that determines its capability to synchronize security policies.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__has_sync_compatibility

    @has_sync_compatibility.setter
    def has_sync_compatibility(self, has_sync_compatibility):

        self.__has_sync_compatibility = has_sync_compatibility

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(SyncPolicy, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        # handle unknown fields
        result['_unknown_fields'] = {}
        unknown = self.get_unknown_fields()
        if sanitize:
            unknown = self._sanitize_for_serialization(unknown)

        return {**result, **unknown}


    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

